#!/bin/sh
#set -x

if test $# -lt 5; then
    echo "Usage: $0 <rbs_rb_working_directory> <product_name_prefix> <instrument_name> <recipe_name> <recipe_arguments>" >&2
    exit 1
fi

rbs_rb_working_directory=$1
product_name_prefix=$2
instrument_name=$3
recipe_name=$4

shift 4

recipe_argv=$*

if test x${instrument_name} != xmuse; then
    echo "ERROR: $0: instrument name=${instrument_name} is not supported!" >&2
    exit 1
fi

if test ! -d ${rbs_rb_working_directory}; then
    echo "ERROR: $0: rbs_rb_working_directory=${rbs_rb_working_directory} does not exist or is no directory" >&2
    exit 1
fi


# Configure esorex runtime environment for MUSE
#
# Keep recipe configuration in sync with recipe
# definitions in the OCA rule file!


export OMP_NUM_THREADS=24
export CPL_MEMORY_MODE=0

# Use image based format for pixel tables to speed up IO
export MUSE_PIXTABLE_SAVE_AS_IMAGE=1


suppress_link="TRUE"
suppress_prefix="TRUE"


case $recipe_name in
detmon_opt_lg_mr)
    thread_pinning="no"
    ;;
muse_ampl|muse_bias|muse_dark|muse_flat|muse_wavecal)
    thread_pinning="yes"
    ;;
muse_lsf)
    thread_pinning="yes"
    ;;
muse_lingain)
    OMP_NUM_THREADS=6
    thread_pinning="yes"
    ;;
muse_geometry)
    OMP_NUM_THREADS=6
    thread_pinning="yes"
    ;;
muse_twilight)
    thread_pinning="yes"
    ;;
muse_scibasic)
    thread_pinning="yes"
    ;;
muse_create_sky)
    thread_pinning="yes"
    ;;
muse_standard)
    thread_pinning="yes"
    ;;
muse_astrometry)
    thread_pinning="yes"
    ;;
muse_scipost)
    thread_pinning="yes"
    ;;
*)
   echo "ERROR: $0: recipe=${recipe_name} is not supported (recipe runtime configuration is missing)!" >&2
   exit 1
   ;;
esac

cpu_max=$((OMP_NUM_THREADS - 1))


# Execute esorex

if test x"$thread_pinning" == xyes; then
    esorex_cmd="/opt/likwid/bin/likwid-pin -c N:0-${cpu_max} /opt/dfs/bin/esorex"
else
    esorex_cmd="/opt/dfs/bin/esorex"
fi

recipe_cmd="${esorex_cmd}"
recipe_cmd="${recipe_cmd} --output-dir=${rbs_rb_working_directory}"
recipe_cmd="${recipe_cmd} --output-prefix=${product_name_prefix}"
recipe_cmd="${recipe_cmd} --suppress-link=${suppress_link}"
recipe_cmd="${recipe_cmd} --suppress-prefix=${suppress_prefix}"
recipe_cmd="${recipe_cmd} --recipe-dir=/usr/lib64/esopipes-plugins"
recipe_cmd="${recipe_cmd} --log-dir=${DFS_LOG}"
recipe_cmd="${recipe_cmd} --log-file=${product_name_prefix}.log"

# FIXME: Temporary workaround since esorex looks for ARCFILE
#        in the header which is not present for intermediate
#        products, and esorex wants it even if no pkd entry
#        is defined! So it is forced to be off!

if test x${disable_qc} != xyes; then
  recipe_cmd="${recipe_cmd} --paf-config=/usr/share/esopipes/pkd/${instrument_name}.pkd"
fi

recipe_cmd="${recipe_cmd} ${recipe_name} ${recipe_argv}"


echo "INFO: $0: Executing recipe command: ${recipe_cmd}"

eval ${recipe_cmd}

if test $? -ne 0; then
    echo "ERROR: $0: esorex failed on recipe ${recipe_name}!" >&2
    exit 1
fi

exit 
